<?php
/**
 * @package    CComment
 * @author     DanielDimitrov <daniel@compojoom.com>
 * @date       22.10.14
 *
 * @copyright  Copyright (C) 2008 - 2013 compojoom.com . All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

defined('_JEXEC') or die('Direct Access to this location is not allowed.');

/**
 * Class ccommentConfig
 *
 * @since  5.0
 */
class ccommentConfig
{
	protected $component = null;

	private static $instances = array();

	protected function __construct()
	{
	}

	protected function __clone()
	{
	}

	/**
	 * @param $component
	 *
	 * @return mixed
	 */
	public static function getConfig($component)
	{
		if (!isset(self::$instances[$component]))
		{
			self::$instances[$component] = self::_createConfig($component);
		}

		return self::$instances[$component];
	}

	/**
	 * @param $component
	 *
	 * @return JRegistry
	 * @throws Exception
	 */
	private static function &_createConfig($component)
	{
		$database = JFactory::getDBO();

		$query = 'SELECT * FROM ' . $database->qn('#__comment_setting')
			. ' WHERE component = ' . $database->Quote($component);

		$database->setQuery($query);
		$row = $database->loadObject();

		if (!$row)
		{
			throw new Exception('No ccomment configuration exist for ' . $component);
		}

		$config = new JRegistry($row->params);

		// Load the global parameters
		$params = JComponentHelper::getParams('com_comment');
		$config->loadArray($params->toArray());

		// We need arrays of those values
		$config->set('global.censorship_word_list', self::censorWords($config->get('global.censorship_word_list')));
		$config->set('basic.exclude_content_items', self::makeArray($config->get('basic.exclude_content_items')));
		$config->set('basic.disable_additional_comments', self::makeArray($config->get('basic.disable_additional_comments')));

		return $config;
	}

	/**
	 * @param $string
	 *
	 * @return array
	 */
	private static function makeArray($string)
	{
		$strings = array();

		if ($string)
		{
			$strings = explode(',', $string);

			foreach ($strings as $key => $value)
			{
				$strings[$key] = trim($value);
			}
		}

		return $strings;
	}

	/**
	 * Transforms the censorship words from a string to an array of words
	 *
	 * @param $censorshipWords
	 *
	 * @return array
	 */
	private static function censorWords($censorshipWords)
	{
		$censorshipList = array();

		if ($censorshipWords)
		{
			$censorshipWords = explode(',', $censorshipWords);

			if (is_array($censorshipWords))
			{
				foreach ($censorshipWords as $word)
				{
					$word = trim($word);

					if (JString::strpos($word, '='))
					{
						$word = explode('=', $word);
						$from = trim($word[0]);
						$to = trim($word[1]);
					}
					else
					{
						$from = $word;
						$to = ccommentHelperStrings::str_fill(JString::strlen($word), '*');
					}

					$censorshipList[$from] = $to;
				}
			}
		}

		return $censorshipList;
	}
}
